==> koin-core-jvm-3.1.6-sources.jar: commonMain/org/koin/core/registry/PropertyRegistry.kt <==
/*
 * Copyright 2017-2021 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.koin.core.registry

import org.koin.core.Koin
import org.koin.core.logger.Level
import org.koin.mp.KoinPlatformTools

/**
 * Property Registry
 * Save/find all Koin properties
 *
 * @author Arnaud Giuliani
 */
@Suppress("UNCHECKED_CAST")
class PropertyRegistry(internal val _koin: Koin) {

    private val _values: MutableMap<String, Any> = KoinPlatformTools.safeHashMap()

    /**
     * saveProperty all properties to registry
     * @param properties
     */
    fun saveProperties(properties: Map<String, Any>) {
        _koin.logger.log(Level.DEBUG) { "load ${properties.size} properties" }
        _values.putAll(properties)
    }

    /**
     * save a property (key,value)
     */
    internal fun <T : Any> saveProperty(key: String, value: T) {
        _values[key] = value
    }

    /**
     * Delete a property (key,value)
     */
    fun deleteProperty(key: String) {
        _values.remove(key)
    }

    /**
     * Get a property
     * @param key
     */
    fun <T> getProperty(key: String): T? {
        return _values[key] as? T
    }

    fun close() {
        _values.clear()
    }
}

==> koin-core-jvm-3.3.0-sources.jar: commonMain/org/koin/core/registry/PropertyRegistry.kt <==
/*
 * Copyright 2017-2021 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.koin.core.registry

import org.koin.core.Koin
import org.koin.core.logger.Level
import org.koin.mp.KoinPlatformTools

/**
 * Property Registry
 * Save/find all Koin properties
 *
 * @author Arnaud Giuliani
 */
@Suppress("UNCHECKED_CAST")
class PropertyRegistry(internal val _koin: Koin) {

    private val _values: MutableMap<String, Any> = KoinPlatformTools.safeHashMap()

    /**
     * saveProperty all properties to registry
     * @param properties
     */
    fun saveProperties(properties: Map<String, Any>) {
        _koin.logger.debug("load ${properties.size} properties" )
        _values.putAll(properties)
    }

    /**
     * save a property (key,value)
     */
    internal fun <T : Any> saveProperty(key: String, value: T) {
        _values[key] = value
    }

    /**
     * Delete a property (key,value)
     */
    fun deleteProperty(key: String) {
        _values.remove(key)
    }

    /**
     * Get a property
     * @param key
     */
    fun <T> getProperty(key: String): T? {
        return _values[key] as? T
    }

    fun close() {
        _values.clear()
    }
}
